@@ -1,4 +1,4 @@
-from report_generator.report import Report
+from numerous_report_generator.report import Report
 from pathlib import Path
 
 def get_client(auto_generated, instance_id, path_str='..'):
